@@ -5,11 +5,12 @@ use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use DBI;
 use Log::Log4perl qw(:easy);
 Log::Log4perl->easy_init($DEBUG);
-#use Log::Log4perl;
+use Log::Any::Adapter;
 #Log::Log4perl->init("log.conf");
 use Forms::Langues;
 use DataAccess::Dbi::Service;
 #use Devel::Cycle;
+Log::Any::Adapter->set('Log::Log4perl');
 
 sub get_dbh {
     my $dbfile = shift;
