@@ -4,12 +4,14 @@ use warnings;
 use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use DBI;
 use Log::Log4perl qw(:easy);
-Log::Log4perl->easy_init($DEBUG);
 #use Log::Log4perl;
 #Log::Log4perl->init("log.conf");
+Log::Log4perl->easy_init($DEBUG);
+use Log::Any::Adapter;
 use Forms::Langues;
 use DataAccess::Rdb::Service;
 #use Devel::Cycle;
+Log::Any::Adapter->set('Log::Log4perl');
 =for comment
 sub get_dbh {
     my $dbfile = shift;
